@@ -82,7 +82,10 @@ func (Pipe) Run(ctx *context.Context) error {
 func doRun(ctx *context.Context, fpm config.NFPM) error {
 	filters := []artifact.Filter{
 		artifact.ByType(artifact.Binary),
-		artifact.ByGoos("linux"),
+		artifact.Or(
+			artifact.ByGoos("linux"),
+			artifact.ByGoos("ios"),
+		),
 	}
 	if len(fpm.Builds) > 0 {
 		filters = append(filters, artifact.ByIDs(fpm.Builds...))
@@ -136,6 +139,10 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 	// TODO: improve mips handling on nfpm
 	infoArch := binaries[0].Goarch + binaries[0].Goarm + binaries[0].Gomips // key used for the ConventionalFileName et al
 	arch := infoArch + binaries[0].Goamd64                                  // unique arch key
+	infoPlatform := binaries[0].Goos
+	if infoPlatform == "ios" {
+		infoPlatform = "iphoneos-arm64"
+	}
 
 	bindDir := fpm.Bindir
 	if format == termuxFormat {
@@ -266,7 +273,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 
 	info := &nfpm.Info{
 		Arch:            infoArch,
-		Platform:        "linux",
+		Platform:        infoPlatform,
 		Name:            fpm.PackageName,
 		Version:         ctx.Version,
 		Section:         fpm.Section,
@@ -369,8 +376,16 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 	if err != nil {
 		return err
 	}
-	if !strings.HasSuffix(name, "."+format) {
-		name = name + "." + format
+
+	ext := "." + format
+	if packager, ok := packager.(nfpm.PackagerWithExtension); ok {
+		if format != "termux.deb" {
+			ext = packager.ConventionalExtension()
+		}
+	}
+
+	if !strings.HasSuffix(name, ext) {
+		name = name + ext
 	}
 
 	path := filepath.Join(ctx.Config.Dist, name)
